==> open-xchange-core_7.4.0.orig.tar.bz2: open-xchange-core-7.4.0/com.openexchange.jolokia/src/org/jolokia/osgi/servlet/JolokiaServlet.java <==
package org.jolokia.osgi.servlet;

/*
 * Copyright 2009-2013 Roland Huss
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import javax.servlet.*;

import org.apache.commons.logging.Log;
import org.jolokia.http.AgentServlet;
import org.jolokia.osgi.JolokiaActivator;
import org.jolokia.restrictor.Restrictor;
import org.jolokia.util.LogHandler;
import org.osgi.framework.BundleContext;
import org.osgi.util.tracker.ServiceTracker;

/**
 * Extended here for the sole purpose of exporting
 * this servlet to the outside in order that
 * it can be instantiated from another bundle.
 *
 * This service also tracks the availability of a log
 * service in order redirect the servlet logging to
 * the log service (if availabled). Otherwise it uses
 * the servlet's logging facility as fallback.
 *
 * @author roland
 * @since 10.02.11
 */
public class JolokiaServlet extends AgentServlet {

    private static final long serialVersionUID = 23L;

    // Context given in the constructor
    private BundleContext bundleContextGiven;

    // Thread-Locals which will be used for holding the bundle context and
    // the https service during initialization
    private static final ThreadLocal<BundleContext> BUNDLE_CONTEXT_THREAD_LOCAL = new ThreadLocal<BundleContext>();

    // Internal Ox Logging
    private static final Log LOG = com.openexchange.log.Log.loggerFor(JolokiaServlet.class);
    
    /**
     * Constructor with an empty context
     */
    public JolokiaServlet() {
        this(null);
    }

    /**
     * Constructor which associates this servlet with a bundle context
     *
     * @param pContext bundle context to associate with
     */
    public JolokiaServlet(BundleContext pContext) {
        this (pContext,null);
    }

    /**
     * Constructor with a bundle context and a given restrictor
     *
     * @param pContext associated bundle context
     * @param pRestrictor restrictor to use or <code>null</code> if the default
     *        lookup mechanism should be used
     */
    public JolokiaServlet(BundleContext pContext,Restrictor pRestrictor) {
        super(pRestrictor);
        bundleContextGiven = pContext;
    }

    /** {@inheritDoc} */
    @Override
    public void init(ServletConfig pServletConfig) throws ServletException {
        // We are making the bundle context available here as a thread local
        // so that the server detector has access to the bundle in order to detect
        // the Osgi-Environment
        BUNDLE_CONTEXT_THREAD_LOCAL.set(getBundleContext(pServletConfig));
        try {
            super.init(pServletConfig);
        } finally {
            BUNDLE_CONTEXT_THREAD_LOCAL.remove();
        }
    }

    /** {@inheritDoc} */
    @Override
    public void destroy() {
        bundleContextGiven = null;
        super.destroy();
    }

    /**
     * Get the current bundle context. This static method can be used during startup
     * of the agent servlet. At other times, this method will return null
     *
     * @return the current bundle context during adding of a HttpService, null at other
     *         times
     */
    public static BundleContext getCurrentBundleContext() {
        return BUNDLE_CONTEXT_THREAD_LOCAL.get();
    }


    private BundleContext getBundleContext(ServletConfig pServletConfig) {
        // If no bundle context was provided, we are looking up the servlet context
        // for the bundlect context, which will be available usually in servlet extender
        if (bundleContextGiven == null) {
            // try to lookup bundle context from the servlet context
            ServletContext servletContext = pServletConfig.getServletContext();
            return (BundleContext) servletContext.getAttribute("osgi-bundlecontext");
        } else {
            return bundleContextGiven;
        }

    }

    // LogHandler which logs to a LogService if available, otherwise
    // it uses simply the servlets log facility
//    private final class ActivatorLogHandler implements LogHandler {
//
//        private ServiceTracker logTracker;
//
//        private ActivatorLogHandler(ServiceTracker pLogTracker) {
//            logTracker = pLogTracker;
//        }
//
//        /** {@inheritDoc} */
//        public void debug(String message) {
//            doLog(LogService.LOG_DEBUG, message);
//        }
//
//        /** {@inheritDoc} */
//        public void info(String message) {
//            doLog(LogService.LOG_INFO, message);
//        }
//
//        private void doLog(int level, String message) {
//            LogService logService = (LogService) logTracker.getService();
//            if (logService != null) {
//                logService.log(level,message);
//            } else {
//                log(message);
//            }
//        }
//
//        /** {@inheritDoc} */
//        public void error(String message, Throwable t) {
//            LogService logService = (LogService) logTracker.getService();
//            if (logService != null) {
//                logService.log(LogService.LOG_ERROR,message,t);
//            } else {
//                log(message,t);
//            }
//        }
//    }

}

==> open-xchange-core_7.6.1.orig.tar.bz2: open-xchange-core-7.6.1/com.openexchange.jolokia/src/org/jolokia/osgi/servlet/JolokiaServlet.java <==
package org.jolokia.osgi.servlet;

/*
 * Copyright 2009-2013 Roland Huss
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import org.jolokia.http.AgentServlet;
import org.jolokia.restrictor.Restrictor;
import org.osgi.framework.BundleContext;

/**
 * Extended here for the sole purpose of exporting
 * this servlet to the outside in order that
 * it can be instantiated from another bundle.
 *
 * This service also tracks the availability of a log
 * service in order redirect the servlet logging to
 * the log service (if availabled). Otherwise it uses
 * the servlet's logging facility as fallback.
 *
 * @author roland
 * @since 10.02.11
 */
public class JolokiaServlet extends AgentServlet {

    private static final long serialVersionUID = 23L;

    // Context given in the constructor
    private BundleContext bundleContextGiven;

    // Thread-Locals which will be used for holding the bundle context and
    // the https service during initialization
    private static final ThreadLocal<BundleContext> BUNDLE_CONTEXT_THREAD_LOCAL = new ThreadLocal<BundleContext>();

    /**
     * Constructor with an empty context
     */
    public JolokiaServlet() {
        this(null);
    }

    /**
     * Constructor which associates this servlet with a bundle context
     *
     * @param pContext bundle context to associate with
     */
    public JolokiaServlet(BundleContext pContext) {
        this (pContext,null);
    }

    /**
     * Constructor with a bundle context and a given restrictor
     *
     * @param pContext associated bundle context
     * @param pRestrictor restrictor to use or <code>null</code> if the default
     *        lookup mechanism should be used
     */
    public JolokiaServlet(BundleContext pContext,Restrictor pRestrictor) {
        super(pRestrictor);
        bundleContextGiven = pContext;
    }

    /** {@inheritDoc} */
    @Override
    public void init(ServletConfig pServletConfig) throws ServletException {
        // We are making the bundle context available here as a thread local
        // so that the server detector has access to the bundle in order to detect
        // the Osgi-Environment
        BUNDLE_CONTEXT_THREAD_LOCAL.set(getBundleContext(pServletConfig));
        try {
            super.init(pServletConfig);
        } finally {
            BUNDLE_CONTEXT_THREAD_LOCAL.remove();
        }
    }

    /** {@inheritDoc} */
    @Override
    public void destroy() {
        bundleContextGiven = null;
        super.destroy();
    }

    /**
     * Get the current bundle context. This static method can be used during startup
     * of the agent servlet. At other times, this method will return null
     *
     * @return the current bundle context during adding of a HttpService, null at other
     *         times
     */
    public static BundleContext getCurrentBundleContext() {
        return BUNDLE_CONTEXT_THREAD_LOCAL.get();
    }


    private BundleContext getBundleContext(ServletConfig pServletConfig) {
        // If no bundle context was provided, we are looking up the servlet context
        // for the bundlect context, which will be available usually in servlet extender
        if (bundleContextGiven == null) {
            // try to lookup bundle context from the servlet context
            ServletContext servletContext = pServletConfig.getServletContext();
            return (BundleContext) servletContext.getAttribute("osgi-bundlecontext");
        } else {
            return bundleContextGiven;
        }

    }
}
